import com.ibm.eNetwork.ECL.*;

public class SAFilel extends Thread implements HostLPConstants, ECLPSNotify
{

  static final SAFilelResults FilelResults = new SAFilelResults();
  static final ScreenState MyScreenState = new ScreenState();
  Object myLock = new Object();
  ECLPS ps;
  ECLOIA oia;
  CFilelData FileListData;
  Object EndingCallLock;

  public SAFilel(ECLPS InitialPS, ECLOIA InitialOIA, CFilelData InitialFileListData,
                 Object InitialCallLock)
  {
     // the data that we care about.
     ps = InitialPS;
     oia = InitialOIA;
     FileListData = InitialFileListData;
     MyScreenState.UpdateState(SS_FILELIST_START);
     EndingCallLock = InitialCallLock;

  }

  public void run()
  {
     try
     { // Register with the ECL that we want to be notified whenever the
       // screen is updated.  When the event occurs we are NOT assured that
       // a "whole" screen of data is present, only that there screen has
       // been updated in some way.
       ps.RegisterPSEvent(this);
       try
       {
         // Wait for presentation layer to "settle down".
         // wait to a "whole" screen of data.  This should happen when
         // the oia area is allowed to receive input.
         try { sleep(100); }
         catch (InterruptedException e)
         { /* System.out.println("SAFilel: catch sleep InterruptedException"); */ }

         while (oia.InputInhibited() != oia.INHIBIT_NOTINHIBITED)
           try { sleep(100); }
           catch (InterruptedException e)
           { /* System.out.println("SAFilel: catch sleep InterruptedException");  */ }

         // Send the filelist command to the host.
         ps.SendKeys("filel ");
         ps.SendKeys(FileListData.S_FileName);
         ps.SendKeys(" ");
         ps.SendKeys(FileListData.S_FileType);
         ps.SendKeys(" ");
         ps.SendKeys(FileListData.S_Disk);
         ps.SendKeys(ps.ENTER_STR);
       }
       catch(Exception e)
       { System.out.println("SAFilel: SendKeys(Filel) Exception");
       }
     }
     catch(Exception e)
     { System.out.println("SAFilel: Registration Exception");
     }

     synchronized(myLock)
     {

       // The rest of the screen processing will be handled asynchronously whenever
       // notification of screen updates occur.  So the run method will now wait
       // until it is signalled that the filelist command/results handling
       // has completed.
       while (MyScreenState.GetState() != SS_FILELIST_FINISHED)
       { try
         { myLock.wait();
         }
         catch(InterruptedException e)
         { System.out.println("SAFilel: wait Exception");
         }
       }
     }

     // This class will no longer process screens, so unregister
     // with PS.
     try
     { ps.UnregisterPSEvent(this);
     }
     catch(Exception e)
     { System.out.println("SAFilel: UnRegistration Exception");
     }


     // Tell the waiting thread (the "main" thread in the FilelLaunchApp)
     // that we have completed the logon.
     synchronized(EndingCallLock)
     {
       EndingCallLock.notify();
     }
  }


  public void NotifyEvent(ECLPS ps)
  {
     // Look at PS to deterimine which screen we're on
     // take appropriate action.

     // After the filelist command has been entered, the only screen
     // we are looking for is the Filelist results.
     if (FilelResults.recognizes(ps, oia, MyScreenState, FileListData))
     {
       // If the final filelist results screen has been processed,
       // then set the state variable to finished, and allow
       // the run method to complete.
       if (MyScreenState.GetState() == SS_FILELIST_FINISHED)
       { synchronized(myLock)
         { myLock.notify();
         }
       }

       return;
     }
  }

  public void NotifyStop(ECLPS eclps, int reason)
  {
  }

  public void NotifyError(ECLPS eclps, ECLErr e)
  {
  }
}
