import com.ibm.eNetwork.ECL.*;
import java.util.*;


class SAFilelResults extends ScreenAction implements HostLPConstants
{

   // The comments in ScreenAction and in the above code for SAVMLogin
   // should cover the basic logistics here.
   // This class is looking for the results of a filelist.  The footprint
   // for this is the work FILELIST, which appears in row 1, column 10 on
   // our systems.

  final static String[] RESULTS  = { "FILELIST" };

  public SAFilelResults()
  {
     SetFootprint(RESULTS, 10);
  }

  public boolean recognizes(ECLPS ps, ECLOIA oia,
                            ScreenState MyScreenState, CFilelData FileListData)
  {
     int i;
     int pos = startPos;

     for (i = 0; i < rows; i++)
     {
        pos = ps.SearchText(buffer[i], pos, ps.SEARCH_FORWARD);
        if (pos == 0)
           return false;
     }

     // Wait for presentation layer to "settle down".
     try { Thread.sleep(100); }
     catch (InterruptedException e)
     { /* System.out.println("SAFilel: catch sleep InterruptedException"); */ }
     while (oia.InputInhibited() != oia.INHIBIT_NOTINHIBITED)
        try { Thread.sleep(100); }
        catch (InterruptedException e)
        { /* System.out.println("SAFilel: catch sleep InterruptedException"); */ }

     TakeActionOnScreen(ps, MyScreenState, FileListData);

     return true;
  }


  public void TakeActionOnScreen (ECLPS ps, ScreenState MyScreenState, CFilelData FileListData)
  {
    ECLFieldList fieldList;
    ECLField name, location;

    // check that we are not already processing this screen.
    if (MyScreenState.GetState() != SS_FILELIST_SCREEN_PROCESSING)
    {
      int iTotalEntries;
      int iStartEntryForThisScreen;
      int iRowsToCapture;
      int iStartRow;
      int iCurrentRow;

      try
      { char[] temp = new char[81];
        String temp2;

        // Set the screen state so we don't double process the same screen.
        MyScreenState.UpdateState(SS_FILELIST_SCREEN_PROCESSING);

        // Move to the word "Size" on the screen
        //WDW int pos = ps.SearchText("Size", 40, ps.SEARCH_FORWARD);
        int pos = ps.SearchText("Size", 1, ps.SEARCH_FORWARD);

        // Get the next 39 characters.
        if ( (pos != 0) && (pos < ((24 * 80) - 40)) )
        { ps.GetScreen(temp, 80, pos, 39, ps.TEXT_PLANE);

          // Manipulate the temp string "Size=x Line=y" to get x and y.
          // Use white spaces, NULL, and "=" (3D), as delimiters.
          StringTokenizer tokenizer = new StringTokenizer(new String(temp), " \u003D");
          // skip over "Size="
          tokenizer.nextToken();
          // Convert x to an integer
          iTotalEntries = Integer.parseInt(tokenizer.nextToken());

          // Skip over Line=
          tokenizer.nextToken();
          // Convert y to an integer
          iStartEntryForThisScreen = Integer.parseInt(tokenizer.nextToken());

          // Calculate the number of entries on this screen
          iRowsToCapture = iTotalEntries - iStartEntryForThisScreen + 1;
          if (iRowsToCapture > 17) iRowsToCapture = 17;

          // The first entry is at row 3 of the first screen
          if (iStartEntryForThisScreen == 1)
          { iStartRow = 3;
          }
          // For the subsequent screens row 3 is a redundent file name of
          // the last row of the previous screen.  Therefore row 4 has the
          // next file name.
          else
          { iStartRow = 4;
            iRowsToCapture = iRowsToCapture - 1;
          }


          // Loop through the number of entries
          for (iCurrentRow = iStartRow; iCurrentRow < iRowsToCapture + iStartRow; iCurrentRow++)
          { // Grab the current row from the screen and put it in the results window
            if (FileListData.iNumberOfItemsToShow < FileListData.iMaxItemsToShow)
            { ps.GetScreenRect(temp, 80, iCurrentRow, 1, iCurrentRow, 80, ECLPS.TEXT_PLANE);
              temp2 = new String(temp);
              FileListData.SA_FileListResults[FileListData.iNumberOfItemsToShow] = temp2.substring(0, 80);
              FileListData.iNumberOfItemsToShow = FileListData.iNumberOfItemsToShow + 1;
            }
          }

          // If we're on the last row, and we haven't seen all the
          // entries, issue a page down to get the next page.

          if( iStartEntryForThisScreen < iTotalEntries)
          {
            MyScreenState.UpdateState(SS_FILELIST_SCREEN_FINISHED);

            try
            { ps.SendKeys(ECLPS.PAGEDWN_STR);
            }
            catch (Exception e)
            { System.out.println("SAFilelResults: TakeActionOnScreen: ps.SendKeys(pgdn)");
            }
          }
          else
          {
            // We are on the last screen for this filelist so change the
            // screen state, and enter F3 to exit filelist and get the
            // screen back to a known state.
            MyScreenState.UpdateState(SS_FILELIST_FINISHED);

            try
            { ps.SendKeys(ECLPS.F3_STR);
            }
            catch (Exception e)
            { System.out.println("SAFilelResults: TakeActionOnScreen: ps.SendKeys(PF3)");
            }
          }
        }
        return;
      }
      catch (Exception e)
      { System.out.println("SAFilelResults: TakeActionOnScreen: General");
        System.out.println(e.toString());
        e.printStackTrace();
      }
    }
  }
}
